# -*- coding: utf-8 -*-
"""Observing Blocks."""

from typing import List, Optional

from micado.main.MObject import MObject


class ObservingBlockExtra(MObject):
    """An Observing Block."""

    def real_fits_keywords(self, prefixes: Optional[List] = None):
        """Overloaded to not list the TPL keywords explicitly.

        Args:
            prefixes: List of prefixes.
        """
        # TODO: Only one template is allowed for now and should also be
        #       referenced in the raw.
        attrs1 = MObject.real_fits_keywords(self, prefixes=prefixes)
        return {k: v for k, v in attrs1.items() if "TPL" not in k}

    @property
    def scopesim_dictionary(self):
        """Create ScopeSIM dictionary."""
        return {
            "class": self.__class__.__name__,
            "name": self.name,
            "target": self.target,
            "instrument": self.instrument,
            "description": self.__doc__.strip(),
            "templates": [template.scopesim_dictionary for template in self.templates],
        }

    @property
    def obx(self) -> str:
        """OBX file contents for this ObservingBlock.

        Based on example templates from OMEGACAM, VIRCAM and HAWKI.
        """
        sstemplates = [template.obx for template in self.templates]
        stemplates = "\n\n\n".join(sstemplates)
        # TODO: Add propRA, propDec, ra, dec.
        return f"""
name                            "{self.name}"
userComments                    ""
InstrumentComments              ""
userPriority                    "1"
type                            "O"


TARGET.NAME                     "{self.target}"
propRA                          "0.0"
propDec                         "0.0"
diffRA                          "0.0"
diffDec                         "0.0"
equinox                         "J2000"
epoch                           "2000.0"
ra                              "00:00:00.000"
dec                             "00:00:00.000"


CONSTRAINT.SET.NAME             "No Name"
seeing                          "0.8"
sky_transparency                "Clear"
air_mass                        "2.8"
fractional_lunar_illumination   "0.2"
moon_angular_distance           "30"
strehlratio                     "0.0"
twilight                        "0"
watervapour                     "0.0"
atm                             "no constraint"
contrast                        "0.0"
description                     ""


OBSERVATION.DESCRIPTION.NAME    "No name"
instrument                      "{self.instrument}"


{stemplates}



""".lstrip()
