"""The Micado specific Processor class"""

import os

from datetime import datetime

from common.config.Environment import Env
from common.util.Processor import (
    Processor as Processor_common,
    ProcessorError,
    LocalProcessor as LocalProcessor_common,
    LocalProcessorError,
)

from .Pipeline import Pipeline


class Processor(Processor_common):

    Pipeline = Pipeline

    # Send the local python as zip file
    # Default value of send_code, if not specified by the user
    send_code = False
    # Use the dpu_awe_version from the Env to send to the DPU
    dpu_aweversion = Env["dpu_aweversion"]


class DummyDpuConn(object):

    """Dummy DPU connection for the LPU, providing an interface for
    getting the DPU key"""

    datetime_format_key = "%Y%m%d_%H%M%S"

    def __init__(self):
        """initialize"""
        self.key = datetime.now().strftime(self.datetime_format_key)


class LocalProcessor(LocalProcessor_common):

    """Local Processing Unit.

    This is simply a way to provide a similar interface to that provided by the
    dpu module when users run taks locally. From the astro-wise prompt tasks may
    be run on the local machine with commands such as:

    lpu.run('bias', d='2012-03-31', i=1, c=1)"""

    Pipeline = Pipeline

    def _process_jobs(self, job_list):
        """set a dummy dpu_conn on all jobs"""
        dummy = DummyDpuConn()
        for job_dict in job_list:
            for job in job_dict["DPU_JOBS"]:
                job.dpu_conn = dummy
        super()._process_jobs(job_list)
