"""Tools for interfacing with the IRDB."""
import os
from pathlib import Path

import yaml

PATH_HERE = Path(__file__).resolve().parent
# Path in the repository where the IRDB git-submodule is installed.
PATH_IRDB_DEV = PATH_HERE.parent.parent.parent / "irdb"
# Path in site-packages where the IRDB is copied to.
PATH_IRDB_PROD = PATH_HERE.parent.parent / "irdb"

if os.path.exists(PATH_IRDB_DEV):
    PATH_IRDB = PATH_IRDB_DEV
elif os.path.exists(PATH_IRDB_PROD):
    PATH_IRDB = PATH_IRDB_PROD
else:
    raise ValueError(f"Cannot find IRDB: {PATH_IRDB_DEV} or {PATH_IRDB_PROD}")

# TODO: Get all yaml files from from MICADO_default.yaml.
INSTRUMENT = yaml.safe_load(open(PATH_IRDB / "MICADO" / "MICADO.yaml"))
ATMOSPHERE = yaml.safe_load(open(PATH_IRDB / "Armazones" / "Armazones.yaml"))
TELESCOPE = yaml.safe_load(open(PATH_IRDB / "ELT" / "ELT.yaml"))
RELAYOPTICS = yaml.safe_load(open(PATH_IRDB / "MICADO" / "MICADO_Standalone_RO.yaml"))
DETECTORARRAY = yaml.safe_load(open(PATH_IRDB / "MICADO" / "MICADO_H4RG.yaml"))

IRDB_FROM_MW = {
    "DetectorArray": {
        "detector_array_list": "full_detector_array",
        "linearity": "detector_linearity",
    },
    "Telescope": {
        "reflection": "telescope_reflection",
    },
    "Instrument": {
        "static_surfaces": "micado_static_surfaces",
        "ncpas_psf": "micado_ncpas_psf",
    },
    "RelayOptics": {
        "psf": "relay_psf",
        "surface_list": "relay_surface_list",
    },
    "Atmosphere": {},
}

MW_FROM_IRDB = {khw: {v: k for k, v in hw.items()} for khw, hw in IRDB_FROM_MW.items()}


def get_effect(irdb_object: dict, name_effect: str):
    """Get effect from IRDB yaml."""
    name_effect_irdb = IRDB_FROM_MW.get(name_effect, name_effect)
    effects = [
        effect
        for effect in irdb_object["effects"]
        if effect["name"] == name_effect_irdb
    ] + [None]
    return effects[0]
